( cd usr/lib/epiphany-1.6/loaders ; rm -rf libpythonloader.so.0 )
( cd usr/lib/epiphany-1.6/loaders ; ln -sf libpythonloader.so.0.0.0 libpythonloader.so.0 )
( cd usr/lib/epiphany-1.6/loaders ; rm -rf libpythonloader.so )
( cd usr/lib/epiphany-1.6/loaders ; ln -sf libpythonloader.so.0.0.0 libpythonloader.so )
